@@ -3,8 +3,8 @@ from dataclasses import dataclass
 
 @dataclass(frozen=True)
 class Player:
-    id: int
-    name: str
+    id: int = 0
+    name: str = ''
 
 
 @dataclass(frozen=True)
