@@ -1,3 +1,4 @@
+import difflib
 import pandas as pd
 
 from tennisrank.model import Player, Match
@@ -14,6 +15,10 @@ def df_to_matches(df):
         yield Match(winner=winner, loser=loser, point_diff=point_diff, surface=surface)
 
 
+def fuzzy_match(a, b):
+    return difflib.SequenceMatcher(None, a, b).ratio()
+
+
 def load_matches(urls):
     def iter_matches():
         for url in urls:
